@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -25,11 +25,10 @@ class PimCommon::LineEditWithAutoCorrectionPrivate
 {
 public:
     LineEditWithAutoCorrectionPrivate()
-        : mAutoCorrection(new PimCommon::AutoCorrection()),
-          mNeedToDeleteAutoCorrection(true)
+        : mAutoCorrection(new PimCommon::AutoCorrection())
     {
-
     }
+
     ~LineEditWithAutoCorrectionPrivate()
     {
         if (mNeedToDeleteAutoCorrection) {
@@ -37,13 +36,13 @@ public:
         }
     }
 
-    PimCommon::AutoCorrection *mAutoCorrection;
-    bool mNeedToDeleteAutoCorrection;
+    PimCommon::AutoCorrection *mAutoCorrection = nullptr;
+    bool mNeedToDeleteAutoCorrection = true;
 };
 
 LineEditWithAutoCorrection::LineEditWithAutoCorrection(QWidget *parent, const QString &configFile)
-    : PimCommon::SpellCheckLineEdit(parent, configFile),
-      d(new PimCommon::LineEditWithAutoCorrectionPrivate)
+    : PimCommon::SpellCheckLineEdit(parent, configFile)
+    , d(new PimCommon::LineEditWithAutoCorrectionPrivate)
 {
 }
 
@@ -91,4 +90,3 @@ void LineEditWithAutoCorrection::keyPressEvent(QKeyEvent *e)
     }
     PimCommon::SpellCheckLineEdit::keyPressEvent(e);
 }
-
