@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -15,47 +15,31 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include "customtoolsplugin.h"
 #include "customtoolspluginmanager.h"
+#include "customtoolsplugin.h"
+
 #include <KPluginFactory>
 #include <KPluginLoader>
-#include <kpluginmetadata.h>
+#include <KPluginMetaData>
+
+#include <QDebug>
 #include <QFileInfo>
 #include <QSet>
-#include <QDebug>
 
 using namespace PimCommon;
 
-class CustomToolsPluginManagerInstancePrivate
-{
-public:
-    CustomToolsPluginManagerInstancePrivate()
-        : customToolsPluginManager(new CustomToolsPluginManager)
-    {
-    }
-
-    ~CustomToolsPluginManagerInstancePrivate()
-    {
-        delete customToolsPluginManager;
-    }
-
-    CustomToolsPluginManager *customToolsPluginManager;
-};
-
-Q_GLOBAL_STATIC(CustomToolsPluginManagerInstancePrivate, sInstance)
-
 class CustomToolsPluginInfo
 {
 public:
     CustomToolsPluginInfo()
         : plugin(nullptr)
     {
-
     }
+
     QString saveName() const;
 
     KPluginMetaData metaData;
-    PimCommon::CustomToolsPlugin *plugin;
+    PimCommon::CustomToolsPlugin *plugin = nullptr;
 };
 
 QString CustomToolsPluginInfo::saveName() const
@@ -63,8 +47,7 @@ QString CustomToolsPluginInfo::saveName() const
     return QFileInfo(metaData.fileName()).baseName();
 }
 
-namespace
-{
+namespace {
 QString pluginVersion()
 {
     return QStringLiteral("1.0");
@@ -77,8 +60,8 @@ public:
     CustomToolsPluginManagerPrivate(CustomToolsPluginManager *qq)
         : q(qq)
     {
-
     }
+
     QVector<PimCommon::CustomToolsPlugin *> pluginsList() const;
     void initializePluginList();
     void loadPlugin(CustomToolsPluginInfo *item);
@@ -88,8 +71,8 @@ public:
 
 void CustomToolsPluginManagerPrivate::initializePluginList()
 {
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("pimcommon"), [](const KPluginMetaData & md) {
-        return md.serviceTypes().contains(QStringLiteral("PimCommonCustomTools/Plugin"));
+    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(QStringLiteral("pimcommon"), [](const KPluginMetaData &md) {
+        return md.serviceTypes().contains(QLatin1String("PimCommonCustomTools/Plugin"));
     });
 
     QVectorIterator<KPluginMetaData> i(plugins);
@@ -138,12 +121,13 @@ void CustomToolsPluginManagerPrivate::loadPlugin(CustomToolsPluginInfo *item)
 
 CustomToolsPluginManager *CustomToolsPluginManager::self()
 {
-    return sInstance->customToolsPluginManager;
+    static CustomToolsPluginManager s_self;
+    return &s_self;
 }
 
 CustomToolsPluginManager::CustomToolsPluginManager(QObject *parent)
-    : QObject(parent),
-      d(new PimCommon::CustomToolsPluginManagerPrivate(this))
+    : QObject(parent)
+    , d(new PimCommon::CustomToolsPluginManagerPrivate(this))
 {
     d->initializePluginList();
 }
