@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -15,59 +15,32 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-#include "genericplugin.h"
 #include "genericpluginmanager.h"
+#include "genericplugin.h"
 #include "pimcommon_debug.h"
 
-#include <kpluginmetadata.h>
-#include <KPluginLoader>
 #include <KPluginFactory>
-#include <KSharedConfig>
-#include <KConfigGroup>
-#include <qfileinfo.h>
-#include <QVariant>
-#include <QSet>
-#include <QVariantList>
-#include <QDebug>
+#include <KPluginLoader>
+
+#include <QFileInfo>
 
 using namespace PimCommon;
 
-class GenericPluginManagerInstancePrivate
-{
-public:
-    GenericPluginManagerInstancePrivate()
-        : genericPluginManager(new GenericPluginManager)
-    {
-    }
-
-    ~GenericPluginManagerInstancePrivate()
-    {
-        delete genericPluginManager;
-    }
-
-    GenericPluginManager *genericPluginManager;
-};
-
-Q_GLOBAL_STATIC(GenericPluginManagerInstancePrivate, sInstance)
-
 class GenericPluginInfo
 {
 public:
     GenericPluginInfo()
-        : plugin(nullptr),
-          isEnabled(true)
     {
-
     }
+
     QString metaDataFileNameBaseName;
     QString metaDataFileName;
     PimCommon::PluginUtilData pluginData;
-    PimCommon::GenericPlugin *plugin;
-    bool isEnabled;
+    PimCommon::GenericPlugin *plugin = nullptr;
+    bool isEnabled = true;
 };
 
-namespace
-{
+namespace {
 QString pluginVersion()
 {
     return QStringLiteral("1.0");
@@ -80,8 +53,8 @@ public:
     GenericPluginManagerPrivate(GenericPluginManager *qq)
         : q(qq)
     {
-
     }
+
     void loadPlugin(GenericPluginInfo *item);
     QVector<GenericPlugin *> pluginsList() const;
     bool initializePlugins();
@@ -117,9 +90,8 @@ bool GenericPluginManagerPrivate::initializePlugins()
     if (serviceTypeName.isEmpty() || pluginName.isEmpty()) {
         return false;
     }
-    static const QString s_serviceTypeName = serviceTypeName;
-    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(pluginName, [](const KPluginMetaData & md) {
-        return md.serviceTypes().contains(s_serviceTypeName);
+    const QVector<KPluginMetaData> plugins = KPluginLoader::findPlugins(pluginName, [this](const KPluginMetaData &md) {
+        return md.serviceTypes().contains(serviceTypeName);
     });
 
     const QPair<QStringList, QStringList> pair = PimCommon::PluginUtil::loadPluginSetting(configGroupName(), configPrefixSettingKey());
@@ -197,10 +169,9 @@ GenericPlugin *GenericPluginManagerPrivate::pluginFromIdentifier(const QString &
 }
 
 GenericPluginManager::GenericPluginManager(QObject *parent)
-    : QObject(parent),
-      d(new GenericPluginManagerPrivate(this))
+    : QObject(parent)
+    , d(new GenericPluginManagerPrivate(this))
 {
-
 }
 
 GenericPluginManager::~GenericPluginManager()
@@ -233,11 +204,6 @@ QString GenericPluginManager::pluginName() const
     return d->pluginName;
 }
 
-GenericPluginManager *GenericPluginManager::self()
-{
-    return sInstance->genericPluginManager;
-}
-
 QVector<GenericPlugin *> GenericPluginManager::pluginsList() const
 {
     return d->pluginsList();
