@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2017 Montel Laurent <montel@kde.org>
+  Copyright (C) 2017-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -26,6 +26,7 @@
 #include <QDialogButtonBox>
 #include <QPushButton>
 #include <QCheckBox>
+#include <QDebug>
 
 using namespace PimCommon;
 
@@ -52,10 +53,10 @@ LogActivitiesDialog::LogActivitiesDialog(QWidget *parent)
     mClearButton->setObjectName(QStringLiteral("clearbutton"));
     buttonBox->addButton(mClearButton, QDialogButtonBox::ActionRole);
     connect(mClearButton, &QPushButton::clicked, this, &LogActivitiesDialog::slotClear);
-    QPushButton *saveButton = buttonBox->button(QDialogButtonBox::Save);
-    saveButton->setObjectName(QStringLiteral("savebutton"));
-    saveButton->setEnabled(false);;
-    connect(saveButton, &QPushButton::clicked, this, &LogActivitiesDialog::slotSave);
+    mSaveButton = buttonBox->button(QDialogButtonBox::Save);
+    mSaveButton->setObjectName(QStringLiteral("savebutton"));
+    mSaveButton->setEnabled(false);
+    connect(mSaveButton, &QPushButton::clicked, this, &LogActivitiesDialog::slotSave);
 
     mainLayout->addWidget(buttonBox);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &LogActivitiesDialog::reject);
@@ -63,12 +64,13 @@ LogActivitiesDialog::LogActivitiesDialog(QWidget *parent)
 
     connect(PimCommon::LogActivitiesManager::self(), &LogActivitiesManager::logEntryAdded, this, &LogActivitiesDialog::slotLogEntryAdded);
     connect(PimCommon::LogActivitiesManager::self(), &LogActivitiesManager::logEntryCleared, this, &LogActivitiesDialog::slotLogEntryCleared);
-    connect(mLogWidget, &LogActivitiesWidget::textChanged, saveButton, &QPushButton::setEnabled);
+    connect(mLogWidget, &LogActivitiesWidget::textChanged, mSaveButton, &QPushButton::setEnabled);
     mEnableLogActivities->setChecked(PimCommon::LogActivitiesManager::self()->enableLogActivities());
 }
 
 LogActivitiesDialog::~LogActivitiesDialog()
 {
+    disconnect(mLogWidget, &LogActivitiesWidget::textChanged, mSaveButton, &QPushButton::setEnabled);
     writeConfig();
 }
 
