@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,10 +18,6 @@
 #include <QWidget>
 #include <QVBoxLayout>
 
-#include <KAboutData>
-
-#include <KLocalizedString>
-
 #include <QApplication>
 #include <QCommandLineParser>
 
@@ -30,14 +26,10 @@
 int main(int argc, char *argv[])
 {
     QApplication app(argc, argv);
-    KAboutData aboutData(QStringLiteral("testspellchecklineedit"), i18n("Test SpellCheckLineEdit"), QStringLiteral("0.1"));
     QCommandLineParser parser;
-    KAboutData::setApplicationData(aboutData);
     parser.addVersionOption();
     parser.addHelpOption();
-    aboutData.setupCommandLine(&parser);
     parser.process(app);
-    aboutData.processCommandLine(&parser);
 
     QWidget *w = new QWidget;
     QVBoxLayout *vbox = new QVBoxLayout(w);
@@ -50,6 +42,4 @@ int main(int argc, char *argv[])
     w->show();
 
     return app.exec();
-
 }
-
