@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2016 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -23,16 +23,15 @@
 #include <QVariant>
 #include <QMap>
 
-namespace PimCommon
-{
-class PIMCOMMONAKONADI_EXPORT CreateResource  : public QObject
+namespace PimCommon {
+class PIMCOMMONAKONADI_EXPORT CreateResource : public QObject
 {
     Q_OBJECT
 public:
     explicit CreateResource(QObject *parent = nullptr);
     ~CreateResource();
 
-    QString createResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree = false);
+    Q_REQUIRED_RESULT QString createResource(const QString &resources, const QString &name, const QMap<QString, QVariant> &settings, bool synchronizeTree = false);
 
 Q_SIGNALS:
     void createResourceInfo(const QString &);
