@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2015-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2015-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -36,7 +36,6 @@ ImapResourceCapabilitiesManager::ImapResourceCapabilitiesManager(QObject *parent
 
 ImapResourceCapabilitiesManager::~ImapResourceCapabilitiesManager()
 {
-
 }
 
 void ImapResourceCapabilitiesManager::slotInstanceAdded(const Akonadi::AgentInstance &instance)
@@ -53,11 +52,11 @@ void ImapResourceCapabilitiesManager::searchCapabilities(const QString &identifi
 {
     //By default makes it as true.
     mImapResource.insert(identifier, true);
-    const QString service =
-        Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Resource, identifier);
+    const QString service
+        = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Resource, identifier);
     QDBusInterface iface(service,
-        QStringLiteral("/"), QStringLiteral("org.kde.Akonadi.ImapResourceBase"),
-        KDBusConnectionPool::threadConnection(), this);
+                         QStringLiteral("/"), QStringLiteral("org.kde.Akonadi.ImapResourceBase"),
+                         KDBusConnectionPool::threadConnection(), this);
 
     if (iface.isValid()) {
         QDBusPendingCall call = iface.asyncCall(QStringLiteral("serverCapabilities"));
@@ -75,7 +74,7 @@ void ImapResourceCapabilitiesManager::slotCapabilities(QDBusPendingCallWatcher *
     if (reply.isValid()) {
         if (watcher->property("identifier").isValid()) {
             const QStringList capabilities = reply.value();
-            mImapResource.insert(watcher->property("identifier").toString(), capabilities.contains(QStringLiteral("ANNOTATEMORE")));
+            mImapResource.insert(watcher->property("identifier").toString(), capabilities.contains(QLatin1String("ANNOTATEMORE")));
         }
     }
     watcher->deleteLater();
